<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Stretch</name>
    <message>
        <location filename="../Stretch.js" line="+59"/>
        <source>First corner</source>
        <translation>Primer punto de esquina</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Reference point</source>
        <translation>Punto de referencia</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Target point</source>
        <translatorcomment>--exact match--
--file: IsoProject_es.ts--
Especifique punto de destino
Punto objetivo</translatorcomment>
        <translation>Punto objetivo</translation>
    </message>
    <message>
        <location line="+138"/>
        <source>No selected entities in given range</source>
        <translation>Ningún objeto seleccionado en el rango dado</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No entities in given range</source>
        <translation>Ningún objeto en el rango dado</translation>
    </message>
    <message>
        <location filename="../StretchInit.js" line="+2"/>
        <source>&amp;Stretch</source>
        <translation>E&amp;stirar</translation>
    </message>
    <message>
        <location filename="../Stretch.js" line="-158"/>
        <source>Second corner</source>
        <translation>Segunda punto de esquina</translation>
    </message>
</context>
</TS>
